@@ -404,7 +404,7 @@ pango_win32_family_get_type (void)
 {
   static GType object_type = 0;
 
-  if (!object_type)
+  if (G_UNLIKELY (!object_type))
     {
       const GTypeInfo object_info =
       {
@@ -786,6 +786,7 @@ pango_win32_font_description_from_logfont (const LOGFONT *lfp)
 
   description = pango_font_description_new ();
   pango_font_description_set_family (description, family);
+  g_free(family);
   pango_font_description_set_style (description, style);
   pango_font_description_set_weight (description, weight);
   pango_font_description_set_stretch (description, stretch);
@@ -981,6 +982,7 @@ pango_win32_font_description_from_logfontw (const LOGFONTW *lfp)
 
   description = pango_font_description_new ();
   pango_font_description_set_family (description, family);
+  g_free(family);
   pango_font_description_set_style (description, style);
   pango_font_description_set_weight (description, weight);
   pango_font_description_set_stretch (description, stretch);
@@ -1271,7 +1273,7 @@ pango_win32_face_get_type (void)
 {
   static GType object_type = 0;
 
-  if (!object_type)
+  if (G_UNLIKELY (!object_type))
     {
       static const GTypeInfo object_info =
       {
